@@ -158,7 +158,8 @@ class ZoneName {
         "America/Cayenne", "French_Guiana", "America/Cayenne",
         "America/Cayman", "America_Eastern", "America/New_York",
         "America/Chicago", "America_Central", "America/Chicago",
-        "America/Chihuahua", "Mexico_Pacific", "America/Mazatlan",
+        "America/Chihuahua", "America_Central", "America/Chicago",
+        "America/Ciudad_Juarez", "America_Mountain", "America/Denver",
         "America/Coral_Harbour", "America_Eastern", "America/New_York",
         "America/Cordoba", "Argentina", "America/Buenos_Aires",
         "America/Costa_Rica", "America_Central", "America/Chicago",
@@ -238,7 +239,7 @@ class ZoneName {
         "America/North_Dakota/Beulah", "America_Central", "America/Chicago",
         "America/North_Dakota/Center", "America_Central", "America/Chicago",
         "America/North_Dakota/New_Salem", "America_Central", "America/Chicago",
-        "America/Ojinaga", "America_Mountain", "America/Denver",
+        "America/Ojinaga", "America_Central", "America/Chicago",
         "America/Panama", "America_Eastern", "America/New_York",
         "America/Pangnirtung", "America_Eastern", "America/New_York",
         "America/Paramaribo", "Suriname", "America/Paramaribo",
@@ -469,6 +470,7 @@ class ZoneName {
         "Europe/Jersey", "GMT", "Atlantic/Reykjavik",
         "Europe/Kaliningrad", "Europe_Eastern", "Europe/Bucharest",
         "Europe/Kiev", "Europe_Eastern", "Europe/Bucharest",
+        "Europe/Kyiv", "Europe_Eastern", "Europe/Bucharest",
         "Europe/Lisbon", "Europe_Western", "Atlantic/Canary",
         "Europe/Ljubljana", "Europe_Central", "Europe/Paris",
         "Europe/London", "GMT", "Atlantic/Reykjavik",
@@ -774,6 +776,7 @@ class ZoneName {
         "SystemV/YST9YDT", "America/Anchorage",
 
         // From tzdb
+        "Africa/Accra", "Africa/Abidjan",
         "Africa/Addis_Ababa", "Africa/Nairobi",
         "Africa/Asmara", "Africa/Nairobi",
         "Africa/Asmera", "Africa/Nairobi",
@@ -808,50 +811,65 @@ class ZoneName {
         "Africa/Ouagadougou", "Africa/Abidjan",
         "Africa/Porto-Novo", "Africa/Lagos",
         "Africa/Timbuktu", "Africa/Abidjan",
-        "America/Anguilla", "America/Port_of_Spain",
-        "America/Antigua", "America/Port_of_Spain",
+        "America/Anguilla", "America/Puerto_Rico",
+        "America/Antigua", "America/Puerto_Rico",
         "America/Argentina/ComodRivadavia", "America/Argentina/Catamarca",
-        "America/Aruba", "America/Curacao",
+        "America/Aruba", "America/Puerto_Rico",
+        "America/Atikokan", "America/Panama",
         "America/Atka", "America/Adak",
+        "America/Blanc-Sablon", "America/Puerto_Rico",
         "America/Buenos_Aires", "America/Argentina/Buenos_Aires",
         "America/Catamarca", "America/Argentina/Catamarca",
         "America/Cayman", "America/Panama",
-        "America/Coral_Harbour", "America/Atikokan",
+        "America/Coral_Harbour", "America/Panama",
         "America/Cordoba", "America/Argentina/Cordoba",
-        "America/Dominica", "America/Port_of_Spain",
+        "America/Creston", "America/Phoenix",
+        "America/Curacao", "America/Puerto_Rico",
+        "America/Dominica", "America/Puerto_Rico",
         "America/Ensenada", "America/Tijuana",
         "America/Fort_Wayne", "America/Indiana/Indianapolis",
         "America/Godthab", "America/Nuuk",
-        "America/Grenada", "America/Port_of_Spain",
-        "America/Guadeloupe", "America/Port_of_Spain",
+        "America/Grenada", "America/Puerto_Rico",
+        "America/Guadeloupe", "America/Puerto_Rico",
         "America/Indianapolis", "America/Indiana/Indianapolis",
         "America/Jujuy", "America/Argentina/Jujuy",
         "America/Knox_IN", "America/Indiana/Knox",
-        "America/Kralendijk", "America/Curacao",
+        "America/Kralendijk", "America/Puerto_Rico",
         "America/Louisville", "America/Kentucky/Louisville",
-        "America/Lower_Princes", "America/Curacao",
-        "America/Marigot", "America/Port_of_Spain",
+        "America/Lower_Princes", "America/Puerto_Rico",
+        "America/Marigot", "America/Puerto_Rico",
         "America/Mendoza", "America/Argentina/Mendoza",
         "America/Montreal", "America/Toronto",
-        "America/Montserrat", "America/Port_of_Spain",
+        "America/Montserrat", "America/Puerto_Rico",
+        "America/Nassau", "America/Toronto",
+        "America/Nipigon", "America/Toronto",
+        "America/Pangnirtung", "America/Iqaluit",
+        "America/Port_of_Spain", "America/Puerto_Rico",
         "America/Porto_Acre", "America/Rio_Branco",
+        "America/Rainy_River", "America/Winnipeg",
         "America/Rosario", "America/Argentina/Cordoba",
         "America/Santa_Isabel", "America/Tijuana",
         "America/Shiprock", "America/Denver",
-        "America/St_Barthelemy", "America/Port_of_Spain",
-        "America/St_Kitts", "America/Port_of_Spain",
-        "America/St_Lucia", "America/Port_of_Spain",
-        "America/St_Thomas", "America/Port_of_Spain",
-        "America/St_Vincent", "America/Port_of_Spain",
-        "America/Tortola", "America/Port_of_Spain",
-        "America/Virgin", "America/Port_of_Spain",
+        "America/St_Barthelemy", "America/Puerto_Rico",
+        "America/St_Kitts", "America/Puerto_Rico",
+        "America/St_Lucia", "America/Puerto_Rico",
+        "America/St_Thomas", "America/Puerto_Rico",
+        "America/St_Vincent", "America/Puerto_Rico",
+        "America/Thunder_Bay", "America/Toronto",
+        "America/Tortola", "America/Puerto_Rico",
+        "America/Virgin", "America/Puerto_Rico",
+        "America/Yellowknife", "America/Edmonton",
+        "Antarctica/DumontDUrville", "Pacific/Port_Moresby",
         "Antarctica/McMurdo", "Pacific/Auckland",
         "Antarctica/South_Pole", "Pacific/Auckland",
-        "Arctic/Longyearbyen", "Europe/Oslo",
+        "Antarctica/Syowa", "Asia/Riyadh",
+        "Arctic/Longyearbyen", "Europe/Berlin",
         "Asia/Aden", "Asia/Riyadh",
         "Asia/Ashkhabad", "Asia/Ashgabat",
         "Asia/Bahrain", "Asia/Qatar",
+        "Asia/Brunei", "Asia/Kuching",
         "Asia/Calcutta", "Asia/Kolkata",
+        "Asia/Choibalsan", "Asia/Ulaanbaatar",
         "Asia/Chongqing", "Asia/Shanghai",
         "Asia/Chungking", "Asia/Shanghai",
         "Asia/Dacca", "Asia/Dhaka",
@@ -859,6 +877,7 @@ class ZoneName {
         "Asia/Istanbul", "Europe/Istanbul",
         "Asia/Kashgar", "Asia/Urumqi",
         "Asia/Katmandu", "Asia/Kathmandu",
+        "Asia/Kuala_Lumpur", "Asia/Singapore",
         "Asia/Kuwait", "Asia/Riyadh",
         "Asia/Macao", "Asia/Macau",
         "Asia/Muscat", "Asia/Dubai",
@@ -871,10 +890,12 @@ class ZoneName {
         "Asia/Ulan_Bator", "Asia/Ulaanbaatar",
         "Asia/Vientiane", "Asia/Bangkok",
         "Atlantic/Faeroe", "Atlantic/Faroe",
-        "Atlantic/Jan_Mayen", "Europe/Oslo",
+        "Atlantic/Jan_Mayen", "Europe/Berlin",
+        "Atlantic/Reykjavik", "Africa/Abidjan",
         "Atlantic/St_Helena", "Africa/Abidjan",
         "Australia/ACT", "Australia/Sydney",
         "Australia/Canberra", "Australia/Sydney",
+        "Australia/Currie", "Australia/Hobart",
         "Australia/LHI", "Australia/Lord_Howe",
         "Australia/NSW", "Australia/Sydney",
         "Australia/North", "Australia/Darwin",
@@ -888,6 +909,8 @@ class ZoneName {
         "Brazil/DeNoronha", "America/Noronha",
         "Brazil/East", "America/Sao_Paulo",
         "Brazil/West", "America/Manaus",
+        "CET", "Europe/Brussels",
+        "CST6CDT", "America/Chicago",
         "Canada/Atlantic", "America/Halifax",
         "Canada/Central", "America/Winnipeg",
         "Canada/Eastern", "America/Toronto",
@@ -899,6 +922,9 @@ class ZoneName {
         "Chile/Continental", "America/Santiago",
         "Chile/EasterIsland", "Pacific/Easter",
         "Cuba", "America/Havana",
+        "EET", "Europe/Athens",
+        "EST", "America/Panama",
+        "EST5EDT", "America/New_York",
         "Egypt", "Africa/Cairo",
         "Eire", "Europe/Dublin",
         "Etc/GMT+0", "Etc/GMT",
@@ -908,23 +934,32 @@ class ZoneName {
         "Etc/UCT", "Etc/UTC",
         "Etc/Universal", "Etc/UTC",
         "Etc/Zulu", "Etc/UTC",
+        "Europe/Amsterdam", "Europe/Brussels",
         "Europe/Belfast", "Europe/London",
         "Europe/Bratislava", "Europe/Prague",
         "Europe/Busingen", "Europe/Zurich",
+        "Europe/Copenhagen", "Europe/Berlin",
         "Europe/Guernsey", "Europe/London",
         "Europe/Isle_of_Man", "Europe/London",
         "Europe/Jersey", "Europe/London",
+        "Europe/Kiev", "Europe/Kyiv",
         "Europe/Ljubljana", "Europe/Belgrade",
+        "Europe/Luxembourg", "Europe/Brussels",
         "Europe/Mariehamn", "Europe/Helsinki",
+        "Europe/Monaco", "Europe/Paris",
         "Europe/Nicosia", "Asia/Nicosia",
+        "Europe/Oslo", "Europe/Berlin",
         "Europe/Podgorica", "Europe/Belgrade",
         "Europe/San_Marino", "Europe/Rome",
         "Europe/Sarajevo", "Europe/Belgrade",
         "Europe/Skopje", "Europe/Belgrade",
+        "Europe/Stockholm", "Europe/Berlin",
         "Europe/Tiraspol", "Europe/Chisinau",
+        "Europe/Uzhgorod", "Europe/Kyiv",
         "Europe/Vaduz", "Europe/Zurich",
         "Europe/Vatican", "Europe/Rome",
         "Europe/Zagreb", "Europe/Belgrade",
+        "Europe/Zaporozhye", "Europe/Kyiv",
         "GB", "Europe/London",
         "GB-Eire", "Europe/London",
         "GMT", "Etc/GMT",
@@ -932,17 +967,26 @@ class ZoneName {
         "GMT-0", "Etc/GMT",
         "GMT0", "Etc/GMT",
         "Greenwich", "Etc/GMT",
+        "HST", "Pacific/Honolulu",
         "Hongkong", "Asia/Hong_Kong",
-        "Iceland", "Atlantic/Reykjavik",
+        "Iceland", "Africa/Abidjan",
         "Indian/Antananarivo", "Africa/Nairobi",
+        "Indian/Christmas", "Asia/Bangkok",
+        "Indian/Cocos", "Asia/Yangon",
         "Indian/Comoro", "Africa/Nairobi",
+        "Indian/Kerguelen", "Indian/Maldives",
+        "Indian/Mahe", "Asia/Dubai",
         "Indian/Mayotte", "Africa/Nairobi",
+        "Indian/Reunion", "Asia/Dubai",
         "Iran", "Asia/Tehran",
         "Israel", "Asia/Jerusalem",
         "Jamaica", "America/Jamaica",
         "Japan", "Asia/Tokyo",
         "Kwajalein", "Pacific/Kwajalein",
         "Libya", "Africa/Tripoli",
+        "MET", "Europe/Brussels",
+        "MST", "America/Phoenix",
+        "MST7MDT", "America/Denver",
         "Mexico/BajaNorte", "America/Tijuana",
         "Mexico/BajaSur", "America/Mazatlan",
         "Mexico/General", "America/Mexico_City",
@@ -953,13 +997,21 @@ class ZoneName {
         "NZ-CHAT", "Pacific/Chatham",
         "Navajo", "America/Denver",
         "PRC", "Asia/Shanghai",
+        "PST8PDT", "America/Los_Angeles",
+        "Pacific/Chuuk", "Pacific/Port_Moresby",
+        "Pacific/Enderbury", "Pacific/Kanton",
+        "Pacific/Funafuti", "Pacific/Tarawa",
         "Pacific/Johnston", "Pacific/Honolulu",
+        "Pacific/Majuro", "Pacific/Tarawa",
         "Pacific/Midway", "Pacific/Pago_Pago",
-        "Pacific/Ponape", "Pacific/Pohnpei",
+        "Pacific/Pohnpei", "Pacific/Guadalcanal",
+        "Pacific/Ponape", "Pacific/Guadalcanal",
         "Pacific/Saipan", "Pacific/Guam",
         "Pacific/Samoa", "Pacific/Pago_Pago",
-        "Pacific/Truk", "Pacific/Chuuk",
-        "Pacific/Yap", "Pacific/Chuuk",
+        "Pacific/Truk", "Pacific/Port_Moresby",
+        "Pacific/Wake", "Pacific/Tarawa",
+        "Pacific/Wallis", "Pacific/Tarawa",
+        "Pacific/Yap", "Pacific/Port_Moresby",
         "Poland", "Europe/Warsaw",
         "Portugal", "Europe/Lisbon",
         "ROC", "Asia/Taipei",
@@ -982,6 +1034,7 @@ class ZoneName {
         "UTC", "Etc/UTC",
         "Universal", "Etc/UTC",
         "W-SU", "Europe/Moscow",
+        "WET", "Europe/Lisbon",
         "Zulu", "Etc/UTC",
     };
 
